From 5d4380158bb36dba346548e1252b0dc954d35a80 Mon Sep 17 00:00:00 2001
From: dg <dg@51575b47-30f0-44d4-a5cc-537603b46e54>
Date: Sun, 9 Dec 2012 22:00:52 +0000
Subject: [PATCH] Rod of Recall gets a notification when picked up Buffed
 Frozen Ground and Shatter

git-svn-id: http://svn.net-core.org/repos/t-engine4@6024 51575b47-30f0-44d4-a5cc-537603b46e54
---
 .../modules/tome/data/general/objects/quest-artifacts.lua | 6 ++++++
 game/modules/tome/data/talents/spells/ice.lua             | 8 ++++----
 2 files changed, 10 insertions(+), 4 deletions(-)

diff --git a/game/modules/tome/data/general/objects/quest-artifacts.lua b/game/modules/tome/data/general/objects/quest-artifacts.lua
index 85411a0475..401e239fec 100644
--- a/game/modules/tome/data/general/objects/quest-artifacts.lua
+++ b/game/modules/tome/data/general/objects/quest-artifacts.lua
@@ -352,6 +352,12 @@ You have heard of such items before. They are very useful to adventurers, allowi
 			return true
 		end
 	end,
+
+	on_pickup = function(self, who)
+		if who == game.player then
+			require("engine.ui.Dialog"):simplePopup("Rod of Recall", "You found a Rod of Recall, you can use it to quickly get out of your current zone and return to the worldmap.")
+		end
+	end,
 }
 
 newEntity{ base = "BASE_ROD",
diff --git a/game/modules/tome/data/talents/spells/ice.lua b/game/modules/tome/data/talents/spells/ice.lua
index 28e750c58f..441c89df55 100644
--- a/game/modules/tome/data/talents/spells/ice.lua
+++ b/game/modules/tome/data/talents/spells/ice.lua
@@ -71,7 +71,7 @@ newTalent{
 	target = function(self, t)
 		return {type="ball", range=self:getTalentRange(t), radius=self:getTalentRadius(t), selffire=false, talent=t}
 	end,
-	getDamage = function(self, t) return self:combatTalentSpellDamage(t, 10, 180) end,
+	getDamage = function(self, t) return self:combatTalentSpellDamage(t, 10, 280) end,
 	action = function(self, t)
 		local tg = self:getTalentTarget(t)
 		local grids = self:project(tg, self.x, self.y, DamageType.COLDNEVERMOVE, {dur=4, dam=self:spellCrit(t.getDamage(self, t))})
@@ -98,7 +98,7 @@ newTalent{
 	tactical = { ATTACKAREA = { COLD = function(self, t, target) if target:attr("frozen") then return 2 end return 0 end } },
 	range = 10,
 	requires_target = true,
-	getDamage = function(self, t) return self:combatTalentSpellDamage(t, 10, 180) end,
+	getDamage = function(self, t) return self:combatTalentSpellDamage(t, 10, 320) end,
 	getTargetCount = function(self, t) return math.ceil(self:getTalentLevel(t) + 2) end,
 	action = function(self, t)
 		local max = t.getTargetCount(self, t)
@@ -117,7 +117,7 @@ newTalent{
 				if not act.dead then
 					local add_crit = 0
 					if act.rank == 2 then add_crit = 50
-					elseif act.rank == 3 then add_crit = 10 end
+					elseif act.rank >= 3 then add_crit = 25 end
 					local tg = {type="hit", friendlyfire=false, talent=t}
 					local grids = self:project(tg, act.x, act.y, DamageType.COLD, self:spellCrit(t.getDamage(self, t), add_crit))
 					game.level.map:particleEmitter(act.x, act.y, tg.radius, "ball_ice", {radius=1})
@@ -137,7 +137,7 @@ newTalent{
 		Depending on the target's rank, there will also be an additional effect:
 		* Critters will be instantly killed
 		* +50%% critical chance against Normal rank
 		* +10%% critical chance against Elites
 		At most it will affect %d foes.
 		The damage will increase with your Spellpower.]]):
 		format(damDesc(self, DamageType.COLD, damage), targetcount)
@@ -137,7 +137,7 @@ newTalent{
 		* Critters will be instantly killed
 		* +50%% critical chance against Normal rank
-		* +10%% critical chance against Elites
+		* +25%% critical chance against Elites or Bosses
 		At most it will affect %d foes.
 		The damage will increase with your Spellpower.]]):
-- 
GitLab